========
Examples
========

We have more at: https://github.com/bearstech/nuka/tree/master/examples


Docker container
================

.. literalinclude:: ../examples/docker_container.py

Docker compose
================

.. literalinclude:: ../examples/docker-compose.yml

.. literalinclude:: ../examples/docker_compose.py

Vagrant
=======

You need to run ``vagrant up`` manually.

.. literalinclude:: ../examples/vagrant.py

GCE
===

.. literalinclude:: ../examples/gce.py
